@@ -5,10 +5,10 @@
 ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, rownames = NULL, colnames = NULL, format = "f", digits = 0, decimal.mark = ".", na.print = "", caption = NULL, caption.level = NULL, width = 0, frame = NULL, grid = NULL, valign = NULL, header = TRUE, footer = FALSE, align = NULL, col.width = 1, style = NULL, tgroup = NULL, n.tgroup = NULL, talign = "c", tvalign = "middle", tstyle = "h", bgroup = NULL, n.bgroup = NULL, balign = "c", bvalign = "middle", bstyle = "h", lgroup = NULL, n.lgroup = NULL, lalign = "c", lvalign = "middle", lstyle = "h", rgroup = NULL, n.rgroup = NULL, ralign = "c", rvalign = "middle", rstyle = "h", ...){
 
   if (inherits(x, "ts") && !is.null(ncol(x))) {
-    tp.1 <- trunc(time(x))
-    tp.2 <- trunc(cycle(x))
+    tp.1 <- trunc(stats::time(x))
+    tp.2 <- trunc(stats::cycle(x))
     day.abb <- c("Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat")
-    ROWNAMES <- switch(frequency(x),
+    ROWNAMES <- switch(stats::frequency(x),
         tp.1,
         "Arg2", "Arg3",              ## Dummy arguments
         paste(tp.1, c("Q1", "Q2", "Q3", "Q4")[tp.2], sep=" "),
@@ -19,7 +19,7 @@ ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, rowna
     tmp <- data.frame(x, row.names=ROWNAMES);
   }
   else if (inherits(x, "ts") && is.null(ncol(x))) {
-    COLNAMES <- switch(frequency(x),
+    COLNAMES <- switch(stats::frequency(x),
         "Value",
         "Arg2", "Arg3",              ## Dummy arguments
         c("Q1", "Q2", "Q3", "Q4"),
@@ -27,10 +27,10 @@ ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, rowna
         day.abb,
         "Arg8", "Arg9", "Arg10", "Arg11",
         month.abb)
-    ROWNAMES <- seq(from=start(x)[1], to=end(x)[1])
-    tmp <- data.frame(matrix(c(rep(NA, start(x)[2] - 1), x,
-              rep(NA, frequency(x) - end(x)[2])),
-            ncol=frequency(x), byrow=TRUE), row.names=ROWNAMES)
+    ROWNAMES <- seq(from=stats::start(x)[1], to=stats::end(x)[1])
+    tmp <- data.frame(matrix(c(rep(NA, stats::start(x)[2] - 1), x,
+              rep(NA, stats::frequency(x) - stats::end(x)[2])),
+            ncol=stats::frequency(x), byrow=TRUE), row.names=ROWNAMES)
     names(tmp) <- COLNAMES
   }
   obj <- asciiTable$new(x = as.data.frame(tmp), include.rownames = include.rownames,
@@ -53,5 +53,5 @@ ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, rowna
 ##' @export
 ##' @method ascii zoo
 ascii.zoo <- function(x, ...) {
-    return(ascii(as.ts(x), ...))
+    return(ascii(stats::as.ts(x), ...))
 }
