@@ -6,8 +6,12 @@
  *	v1.2 March 1995     -- Fixed a core-dump bug
  *	v1.3 October 1995   -- Fixed a bug that shows up only under ELF.
  *	v2.0 December 1995  -- Interpret ISO-style code table escapes.
- *      v2.1 August 1997    -- merge in changes by Ioannis Tambouras.
- *      v2.2 August 1997    -- merge in changes by Ioannis Tambouras.
+ *	v2.1 August 1997    -- merge in changes by Ioannis Tambouras.
+ *	v2.2 November 1997  -- merge in more changes by Ioannis Tambouras.
+ *      v2.3 November 1997  -- incorporated Colin Plumb's splash-screen idea.
+ *	v2.4 December 1998  -- additions by Brian Ginsbach.
+ *	v2.5 December 1998  -- -s option by David N. Welton.
+ *      v2.6 June 1999      -- bug fixes by M.R. van Schouwen.
  *
  * Tries to interpret arguments as names or aliases of ascii characters
  * and dumps out *all* the aliases of each. Accepts literal characters,
@@ -24,7 +28,7 @@
  */
 
 
-#define REVISION "$Revision: 1.5 $"
+#define REVISION "$Revision: 1.15 $"
 
 #include <unistd.h>
 #include <stdio.h>
@@ -34,76 +38,80 @@
 typedef char	*string;
 
 static unsigned char terse = 0;
+static unsigned char help = 0;
+static unsigned char line = 0;
 
 enum { decimal, hex, octal } mode;
 
 void print_table(unsigned short delivery);
 
-
 static string cnames[128][15] =
 {
     {"NUL",		"Null", 		(char *)NULL},
     {"SOH",		"Start Of Heading", 	(char *)NULL},
-    {"STX",		"Start Text",		(char *)NULL},
-    {"ETX",		"End Text",		(char *)NULL},
+    {"STX",		"Start of Text",	(char *)NULL},
+    {"ETX",		"End of Text",		(char *)NULL},
     {"EOT",		"End Of Transmission",	(char *)NULL},
-    {"ENQ",		"Enquire",		(char *)NULL},
+    {"ENQ",		"Enquiry",		(char *)NULL},
     {"ACK",		"Acknowledge",		(char *)NULL},
     {"BEL",		"Bell", "\\a", "Alert",	(char *)NULL},
     {"BS", 		"Backspace", "\\b",	(char *)NULL},
-    {"HT",  "TAB",	"Horizontal Tab", "\\t",	(char *)NULL},
+    {"HT",  "TAB",	"Character Tabulation",
+				"Horizontal Tab", "\\t", (char *)NULL},
     {"LF",  "NL",	"Line Feed", "\\n", "Newline",	(char *)NULL},
-    {"VT",		"Vertical Tab", "\\v",		(char *)NULL},
+    {"VT",		"Line Tabulation",
+				"Vertical Tab", "\\v", (char *)NULL},
     {"FF",		"Form Feed", "\\f",		(char *)NULL},
     {"CR",		"Carriage Return", "\\r",	(char *)NULL},
     {"SO", "LS1",	"Shift Out", "Locking Shift 1",	(char *)NULL},
     {"SI", "LS0",	"Shift In", "Locking Shift 0",	(char *)NULL},
     {"DLE",		"Data Link Escape",	(char *)NULL},
-    {"DC1",		"Direct Control 1",	(char *)NULL},
-    {"DC2",		"Direct Control 2",	(char *)NULL},
-    {"DC3",		"Direct Control 3",	(char *)NULL},
-    {"DC4",		"Direct Control 4",	(char *)NULL},
+    {"DC1",		"Device Control 1",	(char *)NULL},
+    {"DC2",		"Device Control 2",	(char *)NULL},
+    {"DC3",		"Device Control 3",	(char *)NULL},
+    {"DC4",		"Device Control 4",	(char *)NULL},
     {"NAK",		"Negative Acknowledge",	(char *)NULL},
     {"SYN",		"Synchronous Idle",	(char *)NULL},
-    {"ETB",		"End Transmission Block",	(char *)NULL},
+    {"ETB",		"End of Transmission Block",	(char *)NULL},
     {"CAN",		"Cancel",		(char *)NULL},
     {"EM",		"End of Medium",	(char *)NULL},
     {"SUB",		"Substitute", 		(char *)NULL},
     {"ESC",		"Escape",		(char *)NULL},
-    {"FS", 		"Form Separator",	(char *)NULL},
+    {"FS", 		"File Separator",	(char *)NULL},
     {"GS", 		"Group Separator",	(char *)NULL},
     {"RS", 		"Record Separator",	(char *)NULL},
-    {"US", 		"Group Separator",	(char *)NULL},
+    {"US", 		"Unit Separator",	(char *)NULL},
     {" ", "SP",		"Space", "Blank",	(char *)NULL},
-    {"!",		"Exclamation Point",
+    {"!",		"Exclamation Mark",
 	 			"Bang", "Excl", "Wow", "Factorial", "Shriek",
 	 			"Pling", "Smash", "Cuss", (char *)NULL},
-    {"\"",		"Double Quote",
-	 			"Quote", "String Quote", "Dirk",
-				"Literal Mark", "Double Glitch",
+    {"\"",		"Quotation Mark",
+				"Double Quote", "Quote", "String Quote",
+				"Dirk", "Literal Mark", "Double Glitch",
 				"# See ' and ` for matching names.",
 				(char *)NULL},
-    {"#",		"Pound",
-	 			"Number", "Sharp", "Crunch", "Mesh",
+    {"#",		"Number Sign",
+				"Pound", "Number", "Sharp", "Crunch", "Mesh",
 	 			"Hex", "Hash", "Flash", "Grid", "Octothorpe",
 				(char *)NULL},
-    {"$",		"Dollar",
-				"Buck", "Cash", "Ding", (char *)NULL},
-    {"%",		"Percent",
+    {"$",		"Currency Sign",
+				"Dollar", "Buck", "Cash", "Ding",
+				(char *)NULL},
+    {"%",		"Percent Sign",
 	 			"Mod", (char *)NULL},
     {"&",		"Ampersand",
 				"Amper", "And", (char *)NULL},
     {"'",		"Apostrophe",
 				"Single Quote", "Close Quote",  "Prime",
-				"Tick", "Pop", "Spark", "Prime", "Glitch",
+				"Tick", "Pop", "Spark", "Glitch",
 				"# See ` and \" for matching names.",
 				(char *)NULL},
-    {"(",		"Open Parenthesis",
+    {"(",		"Left Parenthesis",
 				"Open", "Open Paren",
 				"Left Paren", "Wane", "Sad",
 				"# See `)' for matching names.",
 	 			(char *)NULL},
-    {")",		"Close Parenthesis",
+    {")",		"Right Parenthesis",
 				"Close", "Close Paren",
 				"Right Paren", "Wax", "Happy",
 				"# See `(' for matching names.",
@@ -112,44 +120,44 @@ static string cnames[128][15] =
 				"Star", "Splat", "Aster", "Times", "Gear",
 				"Dingle", "Bug", "Twinkle", "Glob",  
 				(char *)NULL},
-    {"+",		"Plus",
+    {"+",		"Plus Sign",
 				"Add", "Cross", (char *)NULL},
     {",",		"Comma",
 				"Tail", (char *)NULL},
     {"-",		"Hyphen",
 				"Dash", "Minus", "Worm", (char *)NULL}, 
-    {".",		"Period",
+    {".",		"Full Stop",
 				"Dot", "Decimal Point", "Radix Point",
-				"Point", "Full Stop", "Spot", (char *)NULL},
-    {"/",		"Virgule",
+				"Point", "Period", "Spot", (char *)NULL},
+    {"/",		"Solidus",
 				"Slash", "Stroke", "Slant", "Diagonal",
-				"Solidus", "Over", "Slat",
+				"Virgule", "Over", "Slat",
 				"# See `\\' for matching names.",
 				(char *)NULL},
-    {"0",		"Numeral Zero", (char *)NULL},
-    {"1",		"Numeral One", (char *)NULL},
-    {"2",		"Numeral Two", (char *)NULL},
-    {"3",		"Numeral Three", (char *)NULL},
-    {"4",		"Numeral Four", (char *)NULL},
-    {"5",		"Numeral Five", (char *)NULL},
-    {"6",		"Numeral Six", (char *)NULL},
-    {"7",		"Numeral Seven", (char *)NULL},
-    {"8",		"Numeral Eight", (char *)NULL},
-    {"9",		"Numeral Nine", (char *)NULL},
+    {"0",		"Digit Zero", (char *)NULL},
+    {"1",		"Digit One", (char *)NULL},
+    {"2",		"Digit Two", (char *)NULL},
+    {"3",		"Digit Three", (char *)NULL},
+    {"4",		"Digit Four", (char *)NULL},
+    {"5",		"Digit Five", (char *)NULL},
+    {"6",		"Digit Six", (char *)NULL},
+    {"7",		"Digit Seven", (char *)NULL},
+    {"8",		"Digit Eight", (char *)NULL},
+    {"9",		"Digit Nine", (char *)NULL},
     {":",		"Colon",
 				"Double-Dot", (char *)NULL},
     {";",		"Semicolon",
 				"Semi", "Go-on", (char *)NULL},
-    {"<",		"Less Than",
+    {"<",		"Less-than Sign",
 				"Left Angle Bracket", "Read From", "In",
 				"From", "Comesfrom", "Left Funnel",
 				"Left Broket", "Crunch", "Suck",
 				"# See `<' for matching names.",
 	 			 (char *)NULL},
-    {"=",		"Equals",
+    {"=",		"Equals Sign",
 				"Quadrathorp", "Gets", "Becomes", "Half-Mesh",
 				(char *)NULL},
-    {">",		"Greater Than",
+    {">",		"Greater-than sign",
 				"Right Angle" , "Write To", "Into", "Toward",
 				"Out", "To", "Gozinta", "Right Funnel",
 				"Right Broket", "Zap", "Blow",
@@ -157,7 +165,7 @@ static string cnames[128][15] =
 	 			 (char *)NULL},
     {"?",		"Question Mark",
 				"Whatmark", "What", "Ques", (char *)NULL},
-    {"@",		"At Sign",
+    {"@",		"Commercial At",
 				"At", "Each", "Vortex", "Whorl", "Whirlpool",
 				"Cyclone", "Snail", "Rose", (char *)NULL},
     {"A",		"Majuscule A", "Capital A", "Uppercase A",(char*)NULL},
@@ -190,7 +198,7 @@ static string cnames[128][15] =
 				"Bracket", "Bra", "Square",
 				"# See `]' for matching names.",
 	 			 (char *)NULL},
-    {"\\",		"Reversed Virgule",
+    {"\\",		"Reversed Solidus",
 				"Backslash", "Bash", "Backslant", "Backwhack",
 				"Backslat", "Literal", "Escape",
 				"# See `/' for matching names.",
@@ -199,13 +207,13 @@ static string cnames[128][15] =
 				"Unbracket", "Ket", "Unsquare",
 				"# See `]' for matching names.",
 	 			 (char *)NULL},
-    {"^",		"Circumflex",
-				"Caret", "Uparrow", "Hat", "Control", "Boink",
-				"Chevron", "Hiccup",
+    {"^",		"Circumflex Accent",
+				"Circumflex", "Caret", "Uparrow", "Hat",
+				"Control", "Boink", "Chevron", "Hiccup",
 				"Sharkfin", "Fang", (char*)NULL},
-    {"_",		"Underscore",
-				"Underline", "Underbar", "Under", "Score",
-				"Backarrow", "Flatworm", 
+    {"_",		"Low Line",
+				"Underscore", "Underline", "Underbar",
+				"Under", "Score", "Backarrow", "Flatworm", 
 	"# `Backarrow' refers to this character's graphic in 1963 ASCII.",
 				(char*)NULL},
     {"`",		"Grave Accent",
@@ -241,22 +249,22 @@ static string cnames[128][15] =
     {"x",		"Miniscule x", "Small x", "Lowercase x",(char*)NULL},
     {"y",		"Miniscule y", "Small y", "Lowercase y",(char*)NULL},
     {"z",		"Miniscule z", "Small z", "Lowercase z",(char*)NULL},
-    {"{",		"Open Brace",
-				"Left Brace", "Brace", "Left Curly Bracket",
+    {"{",		"Left Curly Bracket",
+				"Left Brace", "Brace", "Open Brace",
 				"Curly", "Leftit", "Embrace",
 				"# See `}' for matching names.",
 	 			 (char *)NULL},
-    {"|",		"Vertical Bar",
+    {"|",		"Vertical Line",
 				"Pipe", "Bar", "Or", "V-Bar", "Spike",
 				"Gozinta", "Thru", (char *)NULL},
-    {"}",		"Close Brace",
-				"Right Brace", "Unbrace","Right Curly Bracket",
+    {"}",		"Right Curly Bracket",
+				"Right Brace", "Unbrace", "Close Brace",
 				"Uncurly", "Rytit", "Bracelet",
 				"# See `{' for matching names.",
 	 			 (char *)NULL},
-    {"~",		"Tilde",
-				"Swung Dash", "Squiggle", "Approx", "Wiggle",
-				"Twiddle", "Enyay", (char *)NULL},
+    {"~",		"Overline",
+				"Tilde", "Swung Dash", "Squiggle", "Approx",
+				"Wiggle", "Twiddle", "Enyay", (char *)NULL},
     {"DEL",		"Delete", (char *)NULL},
 };
 /******************************************************************/
@@ -282,20 +290,10 @@ char	*str;
 void 
 showHelp(FILE *out, char *progname) 
 {
-  fprintf(out,"Usage: $ %s    [t]    char-alias...\n",progname); 
-  fprintf(out,"       $ %s    [dxo] \n",progname); 
-  fprintf(out,"Options:\n");
-  fprintf(out,"   -t \t\t  Script-friendly mode with terse output \n");
-  fprintf(out,"   -d \t\t  Ascii table in decimal  \n");
-  fprintf(out,"   -x \t\t  Ascii table in hex      \n");
-  fprintf(out,"   -o \t\t  Ascii table in octal    \n");
-  fprintf(out,"   -h \t\t  This help screen\n");
-  fprintf(out,"   -v \t\t  Version info\n");
-  fprintf(out,"Description:\n");
-  fprintf(out,"Prints all aliases of a given ASCII character.
-Args may be single chars, C escape sequences, English names
-caret escapes for control characters, ASCII mnemonics,
-or numeric values in hex/octal/decimal/binary.\n");
+  fprintf(out,"Usage: %s [-dxohv] [-t] [char-alias...]\n", progname); 
+#define P(s)	puts(s);
+#include "splashscreen.h"
+#undef P
 
   exit(0);
 }
@@ -310,7 +308,11 @@ process_options(int argc, char *argv[], char * opt_string)
 
 	switch (op) {
 	case 't':
+	    terse = 1; 
+	    break;
+	case 's':
 	    terse=1; 
+	    line=1; 
 	    break;
 	case 'd':
             print_table(decimal);
@@ -321,15 +323,15 @@ process_options(int argc, char *argv[], char * opt_string)
 	case 'o':
             print_table(octal);
             exit(0);
+	case '?':
 	case 'h':
-	    showHelp(stdout, argv[0]) ;
+	    help = 1;
 	    break;
 	case 'v':
 	    printf("%s\n",REVISION); exit(0) ;
 	    break;
-	case '?': 
 	default :
-	    showHelp(stderr, argv[0]) ;
+	    help = 1;
 	    break;
         } /*switch*/
     }/*while*/
@@ -367,8 +369,8 @@ int	ch;
     char	**ptr = &cnames[ch][0];
 
     if (terse) {
-        printf("%d/%d   %d   0x%02X   0o%o   %s\n", 
-	       ch / 16, ch % 16, ch, ch, ch, btoa(ch));
+        (void) printf("%d/%d   %d   0x%02X   0o%o   %s\n", 
+		      ch / 16, ch % 16, ch, ch, ch, btoa(ch));
         return;
     }
 
@@ -419,7 +421,8 @@ int	ch;
 	    if (**ptr == '#')
 		commentary = *ptr;
 	    else
-		(void) printf("%s%s ", *ptr, ptr[1] ? "," : "");
+		(void) printf("%s%s ", *ptr, 
+			      (ptr[1] && *ptr[1] != '#') ? "," : "");
 	(void) putchar('\n');
 	if (commentary)
 	    (void) printf("Note: %s\n", commentary+2);
@@ -448,6 +451,14 @@ char *str;
     if (len == 1)
        { speak(str[0]); return; }
 
+    /* process multiple letters */ 
+    if (line == 1) {	
+	for (ch = 0; ch < len; ch ++) {
+	    speak(str[ch]);
+	}
+	return;
+    }
+
     /* interpret ^-escapes as control-character notation */
     if (strcmp(str, "^?") == 0)
          { speak(0x7F); return; } 
@@ -465,9 +476,9 @@ char *str;
     if (len == 2 || len == 3)
     {
 	/* first check for standard mnemonics */
-	if (strcmp(str, "DEL") == 0)
+	if (stricmp(str, "DEL") == 0)
 	    { speak(0x7f); return; }
-	if (strcmp(str, "BL") == 0)
+	if (stricmp(str, "BL") == 0)
 	    { speak(' '); return; }
 	else if (isalpha(str[0]))
 	    for (ch = 0; ch <= 32; ch++)
@@ -478,7 +489,7 @@ char *str;
     /* OK, now try to interpret the string as a numeric */
     if (len > 1 && len < 9)
     {
-	int hval, dval, oval, bval;
+	int hval, dval, oval, bval, spoken = 0;
 
 	dval = oval = hval = bval = -1;
 
@@ -492,19 +503,25 @@ char *str;
 	if (len <= 9 && strspn(str, "01") == len)
 	    bval = atob(str);
 
-	/* accept 0xnn, \xnn and xnn forms for hex */
+	/* accept 0xnn, \xnn, xnn and nnh forms for hex */
 	if (hval == -1)
 	    if ((str[0]=='0'||str[0]=='\\') && tolower(str[1]) == 'x')
 		(void) sscanf(str + 2, "%x", &hval);
 	    else if (tolower(str[0]) == 'x')
 		(void) sscanf(str + 1, "%x", &hval);
+	    else if ((len >= 2) && (len <= 3) &&
+	        (strspn(str,"0123456789ABCDEFabcdef") == (len-1)) &&
+	        (tolower(str[len - 1]) == 'h'))
+		(void) sscanf(str, "%x", &hval);
 
-	/* accept 0onn, \onnn and onnn forms for octal */
+	/* accept 0onn, \onnn, onnn and \nnn forms for octal */
 	if (oval == -1)
 	    if ((str[0]=='0'||str[0]=='\\') && tolower(str[1]) == 'o')
 		(void) sscanf(str + 2, "%o", &oval);
 	    else if (tolower(str[0]) == 'o')
 		(void) sscanf(str + 1, "%o", &oval);
+	    else if (str[0] == '\\' && strspn(str + 1, "0123456789") == len - 1)
+		(void) sscanf(str + 1, "%o", &oval);
 
 	/* accept 0dnnn, \dnnn and dnnn forms for decimal */
 	if (dval == -1)
@@ -520,15 +537,22 @@ char *str;
 	    else if (tolower(str[0]) == 'b')
 		bval = atob(str + 1);
 
-	/* OK, now output only unique values */
-	if (hval > -1)
-	    { speak(hval & 0xff); return; }
-	if (dval > -1 && dval != hval)
-	    { speak(dval & 0xff); return; }
-	if (oval > -1 && oval != dval && oval != hval)
-	    { speak(oval & 0xff); return; }
-	if (bval > -1 && bval != oval && bval != dval && bval != hval)
-	    { speak(bval & 0xff); return; }
+	/* OK, now output all values */
+	if (hval > -1 && hval < 256)
+	    speak(hval & 0xff);
+	if (dval > -1 && dval < 256)
+	    speak(dval & 0xff);
+	if (oval > -1 && oval < 256)
+	    speak(oval & 0xff);
+	if (bval > -1 && bval < 256)
+	    speak(bval & 0xff);
+	if (!(hval==-1 && dval==-1 && oval==-1 && bval==-1))
+	{
+	    if (hval > -1 || dval > -1 || oval > -1 || bval > -1)
+		return;
+	    if (hval < 256 || dval < 256 || oval < 256 || bval < 256)
+		return;
+	}
     }
 
     if (sscanf(str, "%d/%d", &hi, &lo) == 2)    /* code table reference?  */
@@ -558,7 +582,7 @@ char *str;
 	for (ch = 0; ch < 128; ch++)
 	    for (ptr = &cnames[ch][1]; *ptr; ptr++)
 		if (!stricmp(*ptr, canbuf))
-		    { speak(ch); return; }
+		    speak(ch);
     } /* outer if */
 }
 /******************************************************************/
@@ -594,19 +618,18 @@ int main(argc, argv)
 int argc;
 char **argv;
 {
-  char      *optstring="thvxod" ;
+    char      *optstring="tshvxod" ;
 
 
-  process_options(argc, argv, optstring) ;
+    process_options(argc, argv, optstring) ;
 
-
-  if (argc == optind ) { 
-          showHelp(stderr, argv[0]);
-  }else{
-          for(argc--, argv++ ; argc > 0; argv++, argc--)
-                  ascii(*argv) ;
-    }
-  exit(0);
+    if (help || argc == optind)
+	showHelp(stdout, argv[0]);
+    else 
+	while (optind < argc)	    
+	    ascii(argv[optind++]);
+    exit(0);
 }
 /******************************************************************/
 /* ascii.c ends here */
+
